pub struct Histogram { /* private fields */ }Expand description
A histogram.
Implementations
Sourceimpl Histogram
impl Histogram
Sourcepub const fn noop() -> Histogram
pub const fn noop() -> Histogram
Creates a no-op Histogram which does nothing.
Suitable when a handle must be provided that does nothing i.e. a no-op recorder or a layer that disables specific metrics, and so on.
Sourcepub fn record_many<T>(&self, value: T, count: usize)where
T: IntoF64,
pub fn record_many<T>(&self, value: T, count: usize)where
T: IntoF64,
Records a value into the histogram multiple times.