#[non_exhaustive]pub enum BreakerConfigError {
ZeroHalfOpenProbes,
ZeroOpenFor,
OpenForTooLong(Duration),
}Expand description
Why a BreakerConfig was rejected.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ZeroHalfOpenProbes
half_open_probes is zero, so no probe budget exists to recover with.
ZeroOpenFor
open_for is zero, which is not a quarantine at all.
OpenForTooLong(Duration)
open_for exceeds BreakerConfig::MAX_OPEN_FOR.